const autoprefixer = require('autoprefixer');
const path = require('path');
const cpx = require("cpx");
const TerserPlugin = require('terser-webpack-plugin');
const webpack = require('webpack');

const sourcePath = path.join(__dirname, 'source');
const distPath = path.join(__dirname, 'dev');

// Setup environment variables
if (typeof process.env.BUILD_ENVIRONMENT == 'undefined') {
  console.error('Need to set the BUILD_ENVIRONMENT variable');
  process.exit(1)
}
const dotEnvOut = require('dotenv').config({path: `${__dirname}/node_modules/@meltwater/add-content-workflow-core/config/${process.env.BUILD_ENVIRONMENT}.env`});
if (dotEnvOut.error) {
  console.error('Unable to find .env file for BUILD_ENVIRONMENT');
  process.exit(1);
}

module.exports = (env) => {

  return {
    context: sourcePath,

    entry: {
      'add-content-workflow': sourcePath + '/add-content-workflow.module.ts'
    },

    optimization: {
      minimize: false
    },

    output: {
      path: distPath,
      filename: '[name].js',
      library: 'AddContentWorkflow'
    },

    module: {
      rules: [
        {
          test: /\.html$/,
          exclude: /node_modules/,
          loader: 'html-loader'
        },
        {
          test: /\.less$/,
          use : [
            "style-loader",
            {
              loader: "css-loader",
              options: {
                sourceMap:true
              }
            },
            {
              loader: 'postcss-loader',
              options: {
                plugins: function() {
                  return [
                    autoprefixer({
                      remove: false,
                      browsers: ['last 2 versions', 'ie 10']
                    })
                  ];
                }
              }
            },
            "less-loader"
          ]
        },
        {
          test: /\.ts$|\.js$/,
          use: [
            {
              loader: 'ng-annotate-loader',
              options: { ngAnnotate: 'ng-annotate-patched', dynamicImport: true }
            },
            {
              loader: 'ts-loader',
              options: { transpileOnly: true }
            }
          ]
        },
        {
          test: /\.json$/,
          use: [
            'json-loader'
          ]
        }
      ]
    },

    plugins: [
      new webpack.EnvironmentPlugin(process.env)
    ],

    resolve: {
      extensions: ['.ts', '.js', '.json', '.css', '.html'],
      modules: [
        path.resolve(__dirname, 'node_modules'),
        sourcePath
      ]
    },

    stats: {
      children: false,
      warnings: false
    },

    devtool: 'source-map',

    externals: {
      'angular': 'angular',
      'angular-cookies': 'angular.module("ngCookies")',
      'angular-material': 'ngMaterial',
      'angular-material/angular-material.css': 'ngMaterial',
      'angular-translate': 'angular.module("pascalprecht.translate")',
      '@meltwater/gaf-ng-components': 'mwAppComponents',
      'moment': 'moment'
    },

    devServer: {
      contentBase: './source',
      https: false,
      host: 'localhost.meltwater.net',
      allowedHosts: [
        'localhost',
        '127.0.0.1',
        'localhost.meltwater.net'
      ],
      headers: {
        'Access-Control-Allow-Origin': '*',
        'Access-Control-Allow-Headers': '*'
      },
      compress: true,
      port: 9000,
      watchContentBase: true
    },
  }
};
